==> mythplugins-0.21-fixes.tar.bz2: mythplugins/mythweb/modules/tv/tmpl/wap/channel.php <==
<?php
/**
 * Channel detail
 *
 * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-21-fixes/mythplugins/mythweb/modules/tv/tmpl/wap/channel.php $
 * @date        $Date: 2007-12-31 12:38:38 -0800 (Mon, 31 Dec 2007) $
 * @version     $Revision: 15274 $
 * @author      $Author: xris $
 * @license     GPL
 *
 * @package     MythWeb
 *
/**/


    // Print the main page header
        $page_title = 'MythWeb - Channel Detail';
        require_once 'modules/_shared/tmpl/'.tmpl.'/header.php';

    // Print out some header info about this channel and time
        global $this_channel;
?>
<p>
            <form id="program_listing" action="<?php echo root ?>tv/channel/<?php echo $_GET['chanid'] ?>" method="post">
            <center>
            Channel <?php echo $this_channel->channum ?> <?php echo $this_channel->callsign ?><br />
            <?php echo date('D m/d/y', $_SESSION['list_time']) ?><br />

            Jump to<br />
            <select name="date"><?php
            // Find out how many days into the future we should bother checking
                $result = mysql_query('SELECT TO_DAYS(max(starttime)) - TO_DAYS(NOW()) FROM program')
                    or trigger_error('SQL Error: '.mysql_error(), FATAL);
                list($max_days) = mysql_fetch_row($result);
                mysql_free_result($result);
            // Print out the list
                for ($i=-1;$i<=$max_days;$i++) {
                    $time = mktime(0,0,0, date('m'), date('d') + $i, date('Y'));
                    $date = date("Ymd", $time);
                    echo "<option value=\"$time\"";
                    if ($date == date("Ymd", $_SESSION['list_time'])) echo " selected";
                    echo ">".date("D m/d/y" , $time)."</option>";
                }
                ?></select><br />
                <input type="submit" class="submit" value="Jump"><br /><br />
            </center>
            </form>
</p>
<?php
    // Print the shows for today
        print_shows();
    // Print the main page footer
        require_once 'modules/_shared/tmpl/'.tmpl.'/footer.php';

    function print_shows() {
        global $this_channel;
    // No search was performed, just return
        if (!is_array($this_channel->programs))
            return;
    // Display the results
        $row = 0;
        foreach ($this_channel->programs as $show) {
    // Print the content
    ?>
    <?php echo strftime($_SESSION['time_format'], $show->starttime) ?> - 
    <?php echo strftime($_SESSION['time_format'], $show->endtime) ?><br />
<?php
        echo '<a href="'.root.'tv/detail/'.$show->chanid.'/'.$show->starttime.'">'.$show->title.'</a><br />';
        if(strlen($show->subtitle))
            echo '<b>'.$show->subtitle.'</b><br />';
//      if(strlen($show->description))
//          echo $show->description.'<br />';
        echo nice_length($show->length).'<br /><br />';
            $row++;
        }

    }

==> mythplugins-0.23-fixes.tar.bz2: mythplugins/mythweb/modules/tv/tmpl/wap/channel.php <==
<?php
/**
 * Channel detail
 *
 * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-23-fixes/mythplugins/mythweb/modules/tv/tmpl/wap/channel.php $
 * @date        $Date: 2009-08-01 21:50:00 -0700 (Sat, 01 Aug 2009) $
 * @version     $Revision: 21099 $
 * @author      $Author: kormoc $
 * @license     GPL
 *
 * @package     MythWeb
 *
/**/


    // Print the main page header
        $page_title = 'MythWeb - Channel Detail';
        require_once 'modules/_shared/tmpl/'.tmpl.'/header.php';

    // Print out some header info about this channel and time
        global $this_channel;
?>
<p>
            <form id="program_listing" action="tv/channel/<?php echo $_GET['chanid'] ?>" method="post">
            <center>
            <?php echo t('Channel') ?> <?php $this_channel->channum ?> <b><?php echo $this_channel->callsign ?></b><br />
            <?php echo date('D m/d/y', $_SESSION['list_time']) ?><br />

            <?php echo t('Jump to') ?><br />
            <select name="date"><?php
            // Find out how many days into the future we should bother checking
                $result = mysql_query('SELECT TO_DAYS(max(starttime)) - TO_DAYS(NOW()) FROM program')
                    or trigger_error('SQL Error: '.mysql_error(), FATAL);
                list($max_days) = mysql_fetch_row($result);
                mysql_free_result($result);
            // Print out the list
                for ($i=-1;$i<=$max_days;$i++) {
                    $time = mktime(0,0,0, date('m'), date('d') + $i, date('Y'));
                    $date = date("Ymd", $time);
                    echo "<option value=\"$time\"";
                    if ($date == date("Ymd", $_SESSION['list_time'])) echo " selected";
                    echo ">".date("D m/d/y" , $time)."</option>";
                }
                ?></select><br />
                <input type="submit" class="submit" value="<?php echo t('Jump') ?>"><br /><br />
            </center>
            </form>
</p>
<?php
    // Print the shows for today
        print_shows();
    // Print the main page footer
        require_once 'modules/_shared/tmpl/'.tmpl.'/footer.php';

    function print_shows() {
        global $this_channel;
    // No search was performed, just return
        if (!is_array($this_channel->programs))
            return;
    // Display the results
        $row = 0;
        foreach ($this_channel->programs as $show) {

        if(strlen($show->title) <= 0 && strlen($show->subtitle) <= 0)
            continue;

    // Print the content
    ?>
    <?php echo strftime($_SESSION['time_format'], $show->starttime) ?> -
    <?php echo strftime($_SESSION['time_format'], $show->endtime) ?><br />
<?php
        if(strlen($show->subtitle) <= 0)
            echo '<b><a href="tv/detail/'.$show->chanid.'/'.$show->starttime.'">'.$show->title.'</a></b><br />';
        else
            echo '<a href="tv/detail/'.$show->chanid.'/'.$show->starttime.'">'.$show->title.'</a><br />';

        if(strlen($show->subtitle))
            echo '<b>'.$show->subtitle.'</b><br />';
//      if(strlen($show->description))
//          echo $show->description.'<br />';
        echo nice_length($show->length).'<br /><br />';
            $row++;
        }

    }
